ploneintranet.simplesharing.tests package
=========================================

Submodules
----------

ploneintranet.simplesharing.tests.base module
---------------------------------------------

.. automodule:: ploneintranet.simplesharing.tests.base
    :members:
    :undoc-members:
    :show-inheritance:

ploneintranet.simplesharing.tests.test_simplesharing module
-----------------------------------------------------------

.. automodule:: ploneintranet.simplesharing.tests.test_simplesharing
    :members:
    :undoc-members:
    :show-inheritance:

ploneintranet.simplesharing.tests.test_vocabularies module
----------------------------------------------------------

.. automodule:: ploneintranet.simplesharing.tests.test_vocabularies
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ploneintranet.simplesharing.tests
    :members:
    :undoc-members:
    :show-inheritance:
